# Bridgecrew Python Package
[![build status](https://github.com/bridgecrewio/bridgecrew-py/workflows/build/badge.svg)](https://github.com/bridgecrewio/bridgecrew-py/actions?query=workflow%3Abuild) 

Wraps checkov with a bridgecrew cli (does exactly the same)